Struct UnicodeCollationProtocol
Source #[repr(C)]
pub struct UnicodeCollationProtocol {
pub stri_coll: unsafe extern "efiapi" fn(this: *const Self, s1: *const Char16, s2: *const Char16) -> isize,
pub metai_match: unsafe extern "efiapi" fn(this: *const Self, string: *const Char16, pattern: *const Char16) -> bool,
pub str_lwr: unsafe extern "efiapi" fn(this: *const Self, s: *mut Char16),
pub str_upr: unsafe extern "efiapi" fn(this: *const Self, s: *mut Char16),
pub fat_to_str: unsafe extern "efiapi" fn(this: *const Self, fat_size: usize, fat: *const Char8, s: *mut Char16),
pub str_to_fat: unsafe extern "efiapi" fn(this: *const Self, s: *const Char16, fat_size: usize, fat: *mut Char8) -> bool,
pub supported_languages: *const Char8,
}
Formats the value using the given formatter.
Read more
Immutably borrows from an owned value.
Read more
Mutably borrows from an owned value.
Read more
Returns the argument unchanged.
Calls U::from(self).
That is, this conversion is whatever the implementation of
[From]<T> for U chooses to do.
The type returned in the event of a conversion error.
Performs the conversion.
The type returned in the event of a conversion error.
Performs the conversion.